@@ -34,4 +34,4 @@ from .multiflash import multiflash
 from .hazt import haz, vlle
 from .hazb import vlleb
 from .stability import tpd_min, tpd_minimas, lle_init, gmix
-from .ell import lle
+from .lle import lle
